@@ -59,20 +59,30 @@ class CIFAR10_Transforms(AugmentationBase):
 
 class CIFAR10_AlbumTrans(AugmentationBase):
 
+    def __init__(self, augs= None):
+      self.augs = augs
+
     def build_train(self):
-        train_trans = alb.Compose([
-            #alb.Rotate((-7.0, 7.0)),
-            alb.PadIfNeeded(40,40,cv2.BORDER_CONSTANT,[4,4],0),
-            #alb.Cutout(1,16,16, [0.4914, 0.4822, 0.4465]*255),
-            alb.RandomCrop(32,32),
-            alb.HorizontalFlip(),
-            alb.CoarseDropout(1, 8, 8, fill_value= [0.4914*255, 0.4822*255, 0.4465*255]),
-            alb.Normalize(
-                mean=[0.4914, 0.4822, 0.4465],
-                std=[0.2023, 0.1994, 0.2010]
-            ),
-            ToTensor()
-        ])
+        
+        if self.augs is None:
+          train_trans = alb.Compose([
+                                     
+              alb.PadIfNeeded(40,40,cv2.BORDER_CONSTANT,[4,4],0),
+              alb.RandomCrop(32,32, always_apply= True),
+              alb.HorizontalFlip(p= 0.75),
+              alb.CoarseDropout(
+                  max_holes=1, max_height=8, max_width=8, min_holes=1, min_height=8, min_width=8, 
+                  fill_value=[0.4914*255, 0.4822*255, 0.4465*255], always_apply=False, p=0.75
+              ),
+              alb.Normalize(
+                  mean=[0.4914, 0.4822, 0.4465],
+                  std=[0.2023, 0.1994, 0.2010]
+              ),
+              ToTensor()
+          ])
+        else:
+          train_trans = alb.Compose(self.augs)
+        
         return AlbumentationTrans(train_trans)
 
     def build_test(self):
@@ -83,5 +93,4 @@ class CIFAR10_AlbumTrans(AugmentationBase):
             ),
             ToTensor()
         ])
-        return AlbumentationTrans(test_trans)
-
+        return AlbumentationTrans(test_trans)
\ No newline at end of file
